@@ -1,3 +1,4 @@
+import logging
 from adaendra_immutable_dict.AdaendraImmutableDict import AdaendraImmutableDict
 
 from adaendra_python_config_loader.AdaendraConfigsLoader import load_configs
@@ -12,13 +13,20 @@ class AdaendraConfigs(object):
     configs = None
 
     # --- METHODS
+    def __init__(self):
+        logging.info('--1--')
+        AdaendraConfigs.configs = AdaendraConfigs.__AdaendraConfigs(load_configs())
+
     def __new__(cls, config_dict: dict):
+        logging.info('--2--')
         if not AdaendraConfigs.configs:
             AdaendraConfigs.configs = AdaendraConfigs.__AdaendraConfigs(config_dict)
         return AdaendraConfigs.configs
 
     def __getattr__(self, name):
+        logging.info('--3--')
         if not AdaendraConfigs.configs:
+            AdaendraConfigs.configs = AdaendraConfigs.__AdaendraConfigs(load_configs())
             raise AttributeError(
                 f"No configs were loaded on start."
             )
